@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 
+from .setuptools_wrap import setup  # noqa: F401
+
 __author__ = 'The scikit-build team'
 __email__ = 'scikit-build@googlegroups.com'
-__version__ = '0.1.0'
-
-from .distutils_wrap import setup
+__version__ = '0.2.0'
 
+__all__ = ["setup"]
